@@ -24,7 +24,7 @@
 #include "eventview.h"
 #include "viewcalendar.h"
 #include "helper.h"
-#include "helper_p.h"
+
 #include "prefs.h"
 #include "prefs_base.h" // for enums
 
@@ -240,7 +240,7 @@ void AgendaItem::setOccurrenceDateTime(const KDateTime &qd)
 
 QDate AgendaItem::occurrenceDate() const
 {
-    return mOccurrenceDateTime.toTimeSpec(mEventView->preferences()->timeSpec()).date();
+    return mOccurrenceDateTime.toLocalZone().date();
 }
 
 void AgendaItem::setCellXY(int X, int YTop, int YBottom)
@@ -614,7 +614,6 @@ void AgendaItem::expandRight(int dx)
 
 void AgendaItem::dragEnterEvent(QDragEnterEvent *e)
 {
-#ifndef KORG_NODND
     const QMimeData *md = e->mimeData();
     if (KCalUtils::ICalDrag::canDecode(md) || KCalUtils::VCalDrag::canDecode(md)) {
         // TODO: Allow dragging events/todos onto other events to create a relation
@@ -626,9 +625,6 @@ void AgendaItem::dragEnterEvent(QDragEnterEvent *e)
     } else {
         e->ignore();
     }
-#else
-    Q_UNUSED(e);
-#endif
 }
 
 void AgendaItem::addAttendee(const QString &newAttendee)
@@ -655,7 +651,6 @@ void AgendaItem::dropEvent(QDropEvent *e)
     // (not only file, also any other url!), then if it's a vcard,
     // otherwise check for attendees, then if the data is binary,
     // add a binary attachment.
-#ifndef KORG_NODND
     if (!mValid) {
         return;
     }
@@ -680,9 +675,6 @@ void AgendaItem::dropEvent(QDropEvent *e)
             addAttendee(em);
         }
     }
-#else
-    Q_UNUSED(e);
-#endif // KORG_NODND
 }
 
 QList<AgendaItem::QPtr> &AgendaItem::conflictItems()
@@ -843,10 +835,8 @@ void AgendaItem::paintEvent(QPaintEvent *ev)
             !mEventView->preferences()->todosUseCategoryColors()) {
         Todo::Ptr todo = CalendarSupport::todo(mIncidence);
         Q_ASSERT(todo);
-        const QDate dueDate =
-            todo->dtDue().toTimeSpec(CalendarSupport::KCalPrefs::instance()->timeSpec()).date();
-        const QDate today =
-            KDateTime::currentDateTime(CalendarSupport::KCalPrefs::instance()->timeSpec()).date();
+        const QDate dueDate = todo->dtDue().toLocalZone().date();
+        const QDate today = QDate::currentDate();
         const QDate occurrenceDate = this->occurrenceDate();
         if (todo->isOverdue() && today >= occurrenceDate) {
             bgColor = mEventView->preferences()->todoOverdueColor();
@@ -932,26 +922,20 @@ void AgendaItem::paintEvent(QPaintEvent *ev)
     QString shortH;
     QString longH;
     if (!isMultiItem()) {
-        shortH = QLocale::system().toString(mIncidence->dateTime(KCalCore::Incidence::RoleDisplayStart).
-                                            toTimeSpec(mEventView->preferences()->timeSpec()).time(), QLocale::ShortFormat);
+        shortH = QLocale().toString(mIncidence->dateTime(KCalCore::Incidence::RoleDisplayStart).toLocalZone().time(), QLocale::ShortFormat);
 
         if (CalendarSupport::hasEvent(mIncidence)) {
             longH = i18n("%1 - %2",
                          shortH,
-                         QLocale::system().toString(
-                             mIncidence->dateTime(KCalCore::Incidence::RoleEnd).toTimeSpec(
-                                 mEventView->preferences()->timeSpec()).time(), QLocale::ShortFormat));
+                         QLocale().toString(mIncidence->dateTime(KCalCore::Incidence::RoleEnd).toLocalZone().time(), QLocale::ShortFormat));
         } else {
             longH = shortH;
         }
     } else if (!mMultiItemInfo->mFirstMultiItem) {
-        shortH = QLocale::system().toString(
-                     mIncidence->dtStart().toTimeSpec(mEventView->preferences()->timeSpec()).time(), QLocale::ShortFormat);
+        shortH = QLocale().toString(mIncidence->dtStart().toLocalZone().time(), QLocale::ShortFormat);
         longH = shortH;
     } else {
-        shortH = QLocale::system().toString(
-                     mIncidence->dateTime(KCalCore::Incidence::RoleEnd).toTimeSpec(
-                         mEventView->preferences()->timeSpec()).time(), QLocale::ShortFormat);
+        shortH = QLocale().toString(mIncidence->dateTime(KCalCore::Incidence::RoleEnd).toLocalZone().time(), QLocale::ShortFormat);
         longH = i18n("- %1", shortH);
     }
 
@@ -1041,11 +1025,8 @@ void AgendaItem::paintEvent(QPaintEvent *ev)
                 // multi-day, all-day event
                 shortH =
                     i18n("%1 - %2",
-                         QLocale::system().toString(
-                             mIncidence->dtStart().toTimeSpec(mEventView->preferences()->timeSpec()).date()),
-                         QLocale::system().toString(
-                             mIncidence->dateTime(KCalCore::Incidence::RoleEnd).toTimeSpec(
-                                 mEventView->preferences()->timeSpec()).date()));
+                         QLocale().toString(mIncidence->dtStart().toLocalZone().date()),
+                         QLocale().toString(mIncidence->dateTime(KCalCore::Incidence::RoleEnd).toLocalZone().date()));
                 longH = shortH;
 
                 // paint headline
