@@ -290,9 +290,9 @@ public:
 
 protected:
     /* reimplemented from KCalCore::Calendar::CalendarObserver */
-    void calendarIncidenceAdded(const KCalCore::Incidence::Ptr &incidence) Q_DECL_OVERRIDE;
-    void calendarIncidenceChanged(const KCalCore::Incidence::Ptr &incidence) Q_DECL_OVERRIDE;
-    void calendarIncidenceDeleted(const KCalCore::Incidence::Ptr &incidence, const KCalCore::Calendar *calendar) Q_DECL_OVERRIDE;
+    void calendarIncidenceAdded(const KCalCore::Incidence::Ptr &incidence) override;
+    void calendarIncidenceChanged(const KCalCore::Incidence::Ptr &incidence) override;
+    void calendarIncidenceDeleted(const KCalCore::Incidence::Ptr &incidence, const KCalCore::Calendar *calendar) override;
 private:
     //quiet --overloaded-virtual warning
     using KCalCore::Calendar::CalendarObserver::calendarIncidenceDeleted;
@@ -333,9 +333,6 @@ AgendaItem::List AgendaView::Private::agendaItems(const QString &uid) const
 bool AgendaView::Private::mightBeVisible(const KCalCore::Incidence::Ptr &incidence) const
 {
     KCalCore::Todo::Ptr todo = incidence.dynamicCast<KCalCore::Todo>();
-    const KDateTime::Spec timeSpec = q->preferences()->timeSpec();
-    KDateTime firstVisibleDateTime(mSelectedDates.first(), timeSpec);
-    KDateTime lastVisibleDateTime(mSelectedDates.last(), timeSpec);
 
     // KDateTime::toTimeSpec() is expensive, so lets first compare only the date,
     // to see if the incidence is visible.
@@ -350,17 +347,17 @@ bool AgendaView::Private::mightBeVisible(const KCalCore::Incidence::Ptr &inciden
 
     if (!incidence->recurs()) {
         // If DTEND/DTDUE is before the 1st visible column
-        if (incidence->dateTime(KCalCore::Incidence::RoleEnd).date().daysTo(firstVisibleDateTime.date()) > 2) {
+        if (incidence->dateTime(KCalCore::Incidence::RoleEnd).date().daysTo(mSelectedDates.first()) > 2) {
             return false;
         }
 
         // if DTSTART is after the last visible column
-        if (!todo && lastVisibleDateTime.date().daysTo(incidence->dtStart().date()) > 2) {
+        if (!todo && mSelectedDates.last().daysTo(incidence->dtStart().date()) > 2) {
             return false;
         }
 
         // if DTDUE is after the last visible column
-        if (todo && lastVisibleDateTime.date().daysTo(todo->dtDue().date()) > 2) {
+        if (todo && mSelectedDates.last().daysTo(todo->dtDue().date()) > 2) {
             return false;
         }
     }
@@ -452,7 +449,7 @@ void AgendaView::Private::calendarIncidenceChanged(const KCalCore::Incidence::Pt
         KCalCore::Incidence::Ptr originalIncidence = agendaItems.first()->incidence();
 
         if (datesEqual(originalIncidence, incidence)) {
-            foreach (const AgendaItem::QPtr &agendaItem, agendaItems) {
+            for (const AgendaItem::QPtr &agendaItem : qAsConst(agendaItems)) {
                 agendaItem->setIncidence(KCalCore::Incidence::Ptr(incidence->clone()));
                 agendaItem->update();
             }
@@ -575,7 +572,7 @@ void AgendaView::Private::insertIncidence(const KCalCore::Incidence::Ptr &incide
     if (event) {
         const QDate firstVisibleDate = mSelectedDates.first();
         // its crossing bounderies, lets calculate beginX and endX
-        const int duration = event->dtStart().toTimeSpec(q->preferences()->timeSpec()).daysTo(event->dtEnd());
+        const int duration = event->dtStart().toLocalZone().daysTo(event->dtEnd());
         if (insertAtDate < firstVisibleDate) {
             beginX = curCol + firstVisibleDate.daysTo(insertAtDate);
             endX   = beginX + duration;
@@ -593,7 +590,7 @@ void AgendaView::Private::insertIncidence(const KCalCore::Incidence::Ptr &incide
     }
 
     const KDateTime::Spec timeSpec = q->preferences()->timeSpec();
-    const QDate today = KDateTime::currentDateTime(timeSpec).date();
+    const QDate today = QDateTime::currentDateTime().date();
     if (todo && todo->isOverdue() && today >= insertAtDate) {
         mAllDayAgenda->insertAllDayItem(incidence, recurrenceId, curCol, curCol,
                                         createSelected);
@@ -1244,7 +1241,7 @@ void AgendaView::createDayLabels(bool force)
         d->mDateDayLabels.append(dayLabel);
         // if a holiday region is selected, show the holiday name
         const QStringList texts = CalendarSupport::holiday(date);
-        Q_FOREACH (const QString &text, texts) {
+        for (const QString &text : texts) {
             // Compute a small version of the holiday string for AlternateLabel
             const KWordWrap ww = KWordWrap::formatText(fm, topDayLabelBox->rect(), 0, text, -1);
             AlternateLabel *label = new AlternateLabel(ww.truncatedString(), text, text, topDayLabelBox);
@@ -1285,7 +1282,7 @@ void AgendaView::updateDayLabelSizes()
 {
     // First, calculate the maximum text type that fits for all labels
     AlternateLabel::TextType overallType = AlternateLabel::Extensive;
-    foreach (AlternateLabel *label, d->mDateDayLabels) {
+    for (AlternateLabel *label : qAsConst(d->mDateDayLabels)) {
         AlternateLabel::TextType type = label->largestFittingTextType();
         if (type < overallType) {
             overallType = type;
@@ -1545,7 +1542,7 @@ void AgendaView::updateEventDates(AgendaItem *item, bool addIncidence,
         startDt = incidence->dtStart();
         // convert to calendar timespec because we then manipulate it
         // with time coming from the calendar
-        startDt = startDt.toTimeSpec(preferences()->timeSpec());
+        startDt = startDt.toLocalZone();
         startDt = startDt.addDays(daysOffset);
         if (!startDt.isDateOnly()) {
             startDt.setTime(startTime);
@@ -1554,8 +1551,7 @@ void AgendaView::updateEventDates(AgendaItem *item, bool addIncidence,
         if (!endDt.isDateOnly()) {
             endDt.setTime(endTime);
         }
-        if (incidence->dtStart().toTimeSpec(preferences()->timeSpec()) == startDt &&
-                ev->dtEnd().toTimeSpec(preferences()->timeSpec()) == endDt) {
+        if (incidence->dtStart().toLocalZone() == startDt && ev->dtEnd().toLocalZone() == endDt) {
             // No change
             QTimer::singleShot(0, this, SLOT(updateView()));
             return;
@@ -1564,7 +1560,7 @@ void AgendaView::updateEventDates(AgendaItem *item, bool addIncidence,
         startDt = td->hasStartDate() ? td->dtStart() : td->dtDue();
         // convert to calendar timespec because we then manipulate it with time coming from
         // the calendar
-        startDt = startDt.toTimeSpec(preferences()->timeSpec());
+        startDt = startDt.toLocalZone();
         startDt.setDate(thisDate.addDays(td->dtDue().daysTo(startDt)));
         if (!startDt.isDateOnly()) {
             startDt.setTime(startTime);
@@ -1576,7 +1572,7 @@ void AgendaView::updateEventDates(AgendaItem *item, bool addIncidence,
             endDt.setTime(endTime);
         }
 
-        if (td->dtDue().toTimeSpec(preferences()->timeSpec())  == endDt) {
+        if (td->dtDue().toLocalZone() == endDt) {
             // No change
             QMetaObject::invokeMethod(this, "updateView", Qt::QueuedConnection);
             return;
@@ -1677,6 +1673,7 @@ void AgendaView::showDates(const QDate &start, const QDate &end, const QDate &pr
     // and update the view
     setChanges(changes() | DatesChanged);
     fillAgenda();
+    d->mTimeLabelsZone->update();
 }
 
 void AgendaView::showIncidences(const Akonadi::Item::List &incidences, const QDate &date)
@@ -1703,22 +1700,18 @@ void AgendaView::showIncidences(const Akonadi::Item::List &incidences, const QDa
         calendar()->setFilter(nullptr);
     }
 
-    const KDateTime::Spec timeSpec = preferences()->timeSpec();
-    KDateTime start =
-        CalendarSupport::incidence(incidences.first())->dtStart().toTimeSpec(timeSpec);
-    KDateTime end =
-        CalendarSupport::incidence(incidences.first())->dateTime(
-            KCalCore::Incidence::RoleEnd).toTimeSpec(timeSpec);
+    KDateTime start = CalendarSupport::incidence(incidences.first())->dtStart().toLocalZone();
+    KDateTime end = CalendarSupport::incidence(incidences.first())->dateTime(KCalCore::Incidence::RoleEnd).toLocalZone();
     Akonadi::Item first = incidences.first();
     Q_FOREACH (const Akonadi::Item &aitem, incidences) {
-        if (CalendarSupport::incidence(aitem)->dtStart().toTimeSpec(timeSpec) < start) {
+        if (CalendarSupport::incidence(aitem)->dtStart().toLocalZone() < start) {
             first = aitem;
         }
         start = qMin(start,
-                     CalendarSupport::incidence(aitem)->dtStart().toTimeSpec(timeSpec));
+                     CalendarSupport::incidence(aitem)->dtStart().toLocalZone());
         end = qMax(start,
                    CalendarSupport::incidence(aitem)->dateTime(
-                       KCalCore::Incidence::RoleEnd).toTimeSpec(timeSpec));
+                       KCalCore::Incidence::RoleEnd).toLocalZone());
     }
 
     end.toTimeSpec(start);      // allow direct comparison of dates
@@ -1832,9 +1825,8 @@ bool AgendaView::displayIncidence(const  KCalCore::Incidence::Ptr &incidence, bo
     firstVisibleDateTime.setTime(QTime(0, 0));
     KCalCore::DateTimeList dateTimeList;
 
-    const KDateTime incDtStart = incidence->dtStart().toTimeSpec(timeSpec);
-    const KDateTime incDtEnd =
-        incidence->dateTime(KCalCore::Incidence::RoleEnd).toTimeSpec(timeSpec);
+    const KDateTime incDtStart = incidence->dtStart().toLocalZone();
+    const KDateTime incDtEnd = incidence->dateTime(KCalCore::Incidence::RoleEnd).toLocalZone();
 
     bool alreadyAddedToday = false;
 
@@ -1854,7 +1846,7 @@ bool AgendaView::displayIncidence(const  KCalCore::Incidence::Ptr &incidence, bo
                                          startDateTimeWithOffset, lastVisibleDateTime);
         while (rIt.hasNext()) {
             rIt.next();
-            const KDateTime occurrenceDate(rIt.occurrenceStartDate().toTimeSpec(timeSpec));
+            const KDateTime occurrenceDate(rIt.occurrenceStartDate().toLocalZone());
             const bool makesDayBusy =
                 preferences()->colorAgendaBusyDays() && makesWholeDayBusy(rIt.incidence());
             if (makesDayBusy) {
@@ -1875,7 +1867,7 @@ bool AgendaView::displayIncidence(const  KCalCore::Incidence::Ptr &incidence, bo
 
         if (todo && todo->hasDueDate() && !todo->isOverdue()) {
             // If it's not overdue it will be shown at the original date (not today)
-            dateToAdd = todo->dtDue().toTimeSpec(timeSpec);
+            dateToAdd = todo->dtDue().toLocalZone();
 
             // To-dos are drawn with the bottom of the rectangle at dtDue
             // if dtDue is at 00:00, then it should be displayed in the previous day, at 23:59
@@ -1920,7 +1912,7 @@ bool AgendaView::displayIncidence(const  KCalCore::Incidence::Ptr &incidence, bo
             busyEvents.append(event);
         }
 
-        d->insertIncidence(incidence, t->toTimeSpec(timeSpec), t->toTimeSpec(timeSpec), createSelected);
+        d->insertIncidence(incidence, t->toLocalZone(), t->toLocalZone(), createSelected);
     }
 
     // Can be multiday
@@ -2068,13 +2060,9 @@ void AgendaView::startDrag(const Akonadi::Item &incidence)
         qCCritical(CALENDARVIEW_LOG) << "No Calendar set";
         return;
     }
-#ifndef KORG_NODND
     if (QDrag *drag = CalendarSupport::createDrag(incidence, calendar()->timeSpec(), this)) {
         drag->exec();
     }
-#else
-    Q_UNUSED(incidence);
-#endif
 }
 
 void AgendaView::readSettings()
