@@ -43,7 +43,7 @@ class TimeLabels : public QFrame
 public:
     typedef QList<TimeLabels *> List;
 
-    TimeLabels(const QTimeZone &zone, int rows, TimeLabelsZone *parent = Q_NULLPTR, Qt::WindowFlags f = Q_NULLPTR);
+    TimeLabels(const QTimeZone &zone, int rows, TimeLabelsZone *parent = nullptr, Qt::WindowFlags f = nullptr);
 
     /** updates widget's internal state */
     void updateConfig();
@@ -52,10 +52,10 @@ public:
     void setAgenda(Agenda *agenda);
 
     /**  */
-    void paintEvent(QPaintEvent *e) Q_DECL_OVERRIDE;
+    void paintEvent(QPaintEvent *e) override;
 
     /** */
-    void contextMenuEvent(QContextMenuEvent *event) Q_DECL_OVERRIDE;
+    void contextMenuEvent(QContextMenuEvent *event) override;
 
     /** Returns the time zone of this label */
     QTimeZone timeZone() const;
@@ -70,9 +70,9 @@ public:
     */
     QString headerToolTip() const;
 
-    QSize sizeHint() const Q_DECL_OVERRIDE;
+    QSize sizeHint() const override;
 
-    QSize minimumSizeHint() const Q_DECL_OVERRIDE;
+    QSize minimumSizeHint() const override;
 
 private:
     /** update the position of the marker showing the mouse position */
