@@ -21,7 +21,7 @@
 */
 #include "timescaleconfigdialog.h"
 #include "prefs.h"
-#include "helper_p.h"
+
 
 #include <KLocalizedString>
 #include <QIcon>
@@ -114,7 +114,7 @@ TimeScaleConfigDialog::TimeScaleConfigDialog(const PrefsPtr &preferences, QWidge
             selList.append(TimeZoneNamePair(tzWithUTC(zoneId), zoneId));
         }
     }
-    qSort(availList.begin(), availList.end());
+    std::sort(availList.begin(), availList.end());
 
     for (const TimeZoneNamePair &item : qAsConst(availList)) {
         zoneCombo->addItem(item.first, item.second);
@@ -150,6 +150,9 @@ TimeScaleConfigDialog::~TimeScaleConfigDialog()
 void TimeScaleConfigDialog::slotUpdateButton()
 {
     removeButton->setEnabled(listWidget->currentItem());
+    const bool numberElementMoreThanOneElement = (listWidget->count() > 1);
+    upButton->setEnabled(numberElementMoreThanOneElement && (listWidget->currentRow() >= 1));
+    downButton->setEnabled(numberElementMoreThanOneElement && (listWidget->currentRow() < listWidget->count() - 1));
 }
 
 void TimeScaleConfigDialog::okClicked()
